{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'beke' W 'ya' MMM",
    "MMMMW-count-other" => "'beke' 'ya' 'bo' W 'ya' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'beke' 'ya' 'bo' w 'ya' Y",
    "yw-count-other" => "'beke' 'ya' 'bo' w 'ya' Y",
  },
  code => "nso-ZA",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} 'ka' {0}",
  datetime_format_long => "{1} 'ka' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Mos",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Mok",
    "Lam",
  ],
  day_format_narrow => [
    "M",
    "B",
    "R",
    "N",
    "H",
    "M",
    "L",
  ],
  day_format_wide => [
    "Mo\N{U+0161}upologo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labohlano",
    "Mokibelo",
    "Lamorena",
  ],
  day_stand_alone_abbreviated => [
    "Mos",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Mok",
    "Lam",
  ],
  day_stand_alone_narrow => [
    "M",
    "B",
    "R",
    "N",
    "H",
    "M",
    "L",
  ],
  day_stand_alone_wide => [
    "Mo\N{U+0161}upologo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labohlano",
    "Mokibelo",
    "Lamorena",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Before Christ",
    "Anno Domini",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Northern Sotho",
  month_format_abbreviated => [
    "Phere",
    "Dibo",
    "Hlak",
    "Mora",
    "Mei",
    "June",
    "Mose",
    "Agosetose",
    "Lewe",
    "Dipha",
    "Diba",
    "Manth",
  ],
  month_format_narrow => [
    "P",
    "D",
    "H",
    "M",
    "M",
    "P",
    "M",
    "P",
    "L",
    "D",
    "D",
    "M",
  ],
  month_format_wide => [
    "Janeware",
    "Febereware",
    "Mat\N{U+0161}he",
    "Aporele",
    "Mei",
    "June",
    "Julae",
    "Agosetose",
    "Setemere",
    "Oktobore",
    "Nofemere",
    "Disemere",
  ],
  month_stand_alone_abbreviated => [
    "Phere",
    "Dibo",
    "Hlak",
    "Mora",
    "Mei",
    "June",
    "Mose",
    "Agosetose",
    "Lewe",
    "Dipha",
    "Diba",
    "Manth",
  ],
  month_stand_alone_narrow => [
    "P",
    "D",
    "H",
    "M",
    "M",
    "P",
    "M",
    "P",
    "L",
    "D",
    "D",
    "M",
  ],
  month_stand_alone_wide => [
    "Janeware",
    "Febereware",
    "Mat\N{U+0161}he",
    "Aporele",
    "Mei",
    "June",
    "Julae",
    "Agosetose",
    "Setemere",
    "Oktobore",
    "Nofemere",
    "Disemere",
  ],
  name => "Northern Sotho South Africa",
  native_language => "Sesotho sa Leboa",
  native_name => "Sesotho sa Leboa Afrika Borwa",
  native_script => undef,
  native_territory => "Afrika Borwa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1st Kotara",
    "2nd Kotara",
    "3rd Kotara",
    "4th Kotara",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st Kotara",
    "2nd Kotara",
    "3rd Kotara",
    "4th Kotara",
  ],
  quarter_stand_alone_abbreviated => [
    "1st Kotara",
    "2nd Kotara",
    "3rd Kotara",
    "4th Kotara",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st Kotara",
    "2nd Kotara",
    "3rd Kotara",
    "4th Kotara",
  ],
  script => undef,
  territory => "South Africa",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
