{
  am_pm_abbreviated => [
    "am",
    "pm",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM G y",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG d/M/y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "MMMM 't\N{U+00e3}' 'vara' W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "Y 't\N{U+00e3}' 'vara' w",
  },
  code => "kxv-Latn-IN",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "smba",
    "manga",
    "puda",
    "laki",
    "sukru",
    "sani",
    "aadi",
  ],
  day_format_narrow => [
    "s",
    "ma",
    "pu",
    "la",
    "su",
    "sa",
    "aa",
  ],
  day_format_wide => [
    "smbara",
    "manga\N{U+1e0d}a",
    "pudara",
    "laki vara",
    "sukru vara",
    "sani vara",
    "aadi vara",
  ],
  day_stand_alone_abbreviated => [
    "smba",
    "manga",
    "puda",
    "laki",
    "sukru",
    "sani",
    "aadi",
  ],
  day_stand_alone_narrow => [
    "s",
    "ma",
    "pu",
    "la",
    "su",
    "sa",
    "aa",
  ],
  day_stand_alone_wide => [
    "smbara",
    "manga\N{U+1e0d}a",
    "pudara",
    "laki vara",
    "sukru vara",
    "sani vara",
    "aadi vara",
  ],
  era_abbreviated => [
    "bc",
    "ad",
  ],
  era_narrow => [
    "bc",
    "ad",
  ],
  era_wide => [
    "kris\N{U+1e6d} purb nki",
    "kris\N{U+1e6d}abd",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kuvi",
  month_format_abbreviated => [
    "pusu",
    "maha",
    "pagu",
    "hire",
    "bese",
    "ja\N{U+1e6d}\N{U+1e6d}a",
    "aasa\N{U+1e0d}i",
    "srab\N{U+0129}",
    "bado",
    "dasara",
    "divi",
    "pande",
  ],
  month_format_narrow => [
    "pu",
    "ma",
    "pa",
    "hi",
    "be",
    "ja",
    "aa",
    "sra",
    "b",
    "da",
    "di",
    "pa",
  ],
  month_format_wide => [
    "pusu lenju",
    "maha lenju",
    "pagu lenju",
    "hire lenju",
    "bese lenju",
    "ja\N{U+1e6d}\N{U+1e6d}a lenju",
    "aasa\N{U+1e0d}i lenju",
    "srab\N{U+0129} lenju",
    "bado lenju",
    "dasara lenju",
    "divi lenju",
    "pande lenju",
  ],
  month_stand_alone_abbreviated => [
    "pusu",
    "maha",
    "pagu",
    "hire",
    "bese",
    "ja\N{U+1e6d}\N{U+1e6d}a",
    "aasa\N{U+1e0d}i",
    "srab\N{U+0129}",
    "bado",
    "dasara",
    "divi",
    "pande",
  ],
  month_stand_alone_narrow => [
    "pu",
    "ma",
    "pa",
    "hi",
    "be",
    "ja",
    "aa",
    "sra",
    "b",
    "da",
    "di",
    "pa",
  ],
  month_stand_alone_wide => [
    "pusu lenju",
    "maha lenju",
    "pagu lenju",
    "hire lenju",
    "bese lenju",
    "ja\N{U+1e6d}\N{U+1e6d}a lenju",
    "aasa\N{U+1e0d}i lenju",
    "srab\N{U+0129} lenju",
    "bado lenju",
    "dasara lenju",
    "divi lenju",
    "pande lenju",
  ],
  name => "Kuvi India Latin",
  native_language => "kuvi",
  native_name => "kuvi in\N{U+1e0d}i\N{U+0101} la\N{U+1e6d}in",
  native_script => "la\N{U+1e6d}in",
  native_territory => "in\N{U+1e0d}i\N{U+0101}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1s\N{U+1e6d} kuar\N{U+1e6d}r",
    "2n\N{U+1e0d} kuar\N{U+1e6d}r",
    "3r\N{U+1e0d} kuar\N{U+1e6d}r",
    "4th kuar\N{U+1e6d}r",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1s\N{U+1e6d} kuar\N{U+1e6d}r",
    "2n\N{U+1e0d} kuar\N{U+1e6d}r",
    "3r\N{U+1e0d} kuar\N{U+1e6d}r",
    "4th kuar\N{U+1e6d}r",
  ],
  script => "Latin",
  territory => "India",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 46,
}
