{
  am_pm_abbreviated => [
    "am",
    "pm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "MM,dd,y",
    yMd => "d/M/y",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "bal-Latn-PK",
  date_format_full => "dd,MM,y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Do",
    "Say",
    "Ch\N{U+00e1}",
    "Pan",
    "Jom",
    "Sha",
    "Yak",
  ],
  day_format_narrow => [
    "D",
    "S",
    "Ch",
    "P",
    "J",
    "Sh",
    "Y",
  ],
  day_format_wide => [
    "Doshambeh",
    "Sayshambeh",
    "Ch\N{U+00e1}rshambeh",
    "Panchshambeh",
    "Jomah",
    "Shambeh",
    "Yakshambeh",
  ],
  day_stand_alone_abbreviated => [
    "Do",
    "Say",
    "Ch\N{U+00e1}",
    "Pan",
    "Jom",
    "Sha",
    "Yak",
  ],
  day_stand_alone_narrow => [
    "D",
    "S",
    "Ch",
    "P",
    "J",
    "Sh",
    "Y",
  ],
  day_stand_alone_wide => [
    "Doshambeh",
    "Sayshambeh",
    "Ch\N{U+00e1}rshambeh",
    "Panchshambeh",
    "Jomah",
    "Shambeh",
    "Yakshambeh",
  ],
  era_abbreviated => [
    "PM",
    "AD",
  ],
  era_narrow => [
    "PM",
    "AD",
  ],
  era_wide => [
    "P\N{U+00e9}shmil\N{U+00e1}d",
    "Ann\N{U+00f3} Domini",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Baluchi",
  month_format_abbreviated => [
    "Jan",
    "Par",
    "M\N{U+00e1}r",
    "Apr",
    "Mai",
    "Jun",
    "J\N{U+00f3}l",
    "Aga",
    "Sat",
    "Akt",
    "Naw",
    "Das",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Janwari",
    "Parwari",
    "M\N{U+00e1}rch",
    "Apr\N{U+00e9}l",
    "Mai",
    "Jun",
    "J\N{U+00f3}l\N{U+00e1}i",
    "Agast",
    "Satambar",
    "Aktubar",
    "Nawambar",
    "Dasambar",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Par",
    "M\N{U+00e1}r",
    "Apr",
    "Mai",
    "Jun",
    "J\N{U+00f3}l",
    "Aga",
    "Sat",
    "Akt",
    "Naw",
    "Das",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Janwari",
    "Parwari",
    "M\N{U+00e1}rch",
    "Apr\N{U+00e9}l",
    "Mai",
    "Jun",
    "J\N{U+00f3}l\N{U+00e1}i",
    "Agast",
    "Satambar",
    "Aktubar",
    "Nawambar",
    "Dasambar",
  ],
  name => "Baluchi Pakistan Latin",
  native_language => "Bal\N{U+00f3}chi",
  native_name => "Bal\N{U+00f3}chi P\N{U+00e1}kest\N{U+00e1}n L\N{U+00e1}tin Engr\N{U+00e9}zi (L\N{U+00e1}tin) Engr\N{U+00e9}zi (L\N{U+00e1}tin, Amrik\N{U+00e1}ay Tep\N{U+00e1}k\N{U+00e9}n Est\N{U+00e1}n) sy\N{U+00e1}hag: L\N{U+00e1}tini",
  native_script => "L\N{U+00e1}tin Engr\N{U+00e9}zi (L\N{U+00e1}tin) Engr\N{U+00e9}zi (L\N{U+00e1}tin, Amrik\N{U+00e1}ay Tep\N{U+00e1}k\N{U+00e9}n Est\N{U+00e1}n) sy\N{U+00e1}hag: L\N{U+00e1}tini",
  native_territory => "P\N{U+00e1}kest\N{U+00e1}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1/4",
    "2/4",
    "3/4",
    "4/4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "awali ch\N{U+00e1}rek",
    "domi ch\N{U+00e1}rek",
    "sayomi ch\N{U+00e1}rek",
    "ch\N{U+00e1}romi ch\N{U+00e1}rek",
  ],
  quarter_stand_alone_abbreviated => [
    "1/4",
    "2/4",
    "3/4",
    "4/4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "awali ch\N{U+00e1}rek",
    "domi ch\N{U+00e1}rek",
    "sayomi ch\N{U+00e1}rek",
    "ch\N{U+00e1}romi ch\N{U+00e1}rek",
  ],
  script => "Latin",
  territory => "Pakistan",
  time_format_full => "hh:mm:ss\N{U+202f}a zzzz",
  time_format_long => "hh:mm:ss\N{U+202f}a zzz",
  time_format_medium => "hh:mm:ss\N{U+202f}a",
  time_format_short => "hh:mm\N{U+202f}a",
  variant => undef,
  version => 46,
}
