{
  am_pm_abbreviated => [
    "WD",
    "WB",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "'torbee' W 'kan' MMMM",
    "MMMMW-count-other" => "'torbee' W 'kan' MMMM",
    MMMMd => "MMMM d",
    MMMMdd => "MMMM dd",
    MMMd => "MMM d",
    MMdd => "dd/MM",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'torbee' w 'kan' Y",
    "yw-count-other" => "'torbee' w 'kan' Y",
  },
  code => "om-ET",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Wix",
    "Kib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_format_narrow => [
    "W",
    "K",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_format_wide => [
    "Wiixata",
    "Kibxata",
    "Roobii",
    "Kamisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  day_stand_alone_abbreviated => [
    "Wix",
    "Kib",
    "Rob",
    "Kam",
    "Jim",
    "San",
    "Dil",
  ],
  day_stand_alone_narrow => [
    "W",
    "K",
    "R",
    "K",
    "J",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "Wiixata",
    "Kibxata",
    "Roobii",
    "Kamisa",
    "Jimaata",
    "Sanbata",
    "Dilbata",
  ],
  era_abbreviated => [
    "DhKD",
    "BA",
  ],
  era_narrow => [
    "Dh",
    "B",
  ],
  era_wide => [
    "Dhaloota Kiristoos Dura",
    "Bara Araaraa",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A, %B %e, %r %Z %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%A, %B %e, %Y %r %Z",
  glibc_time_12_format => "%l:%M:%S %p",
  glibc_time_format => "%l:%M:%S %p",
  language => "Oromo",
  month_format_abbreviated => [
    "Ama",
    "Gur",
    "Bitootessa",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sadaasa",
    "Mud",
  ],
  month_format_narrow => [
    "A",
    "G",
    "B",
    "E",
    "C",
    "W",
    "A",
    "H",
    "F",
    "O",
    "S",
    "M",
  ],
  month_format_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitootessa",
    "Eebila",
    "Caamsaa",
    "Waxabajjii",
    "Adoolessa",
    "Hagayya",
    "Fulbaana",
    "Onkoloolessa",
    "Sadaasa",
    "Mudde",
  ],
  month_stand_alone_abbreviated => [
    "Ama",
    "Gur",
    "Bitootessa",
    "Elb",
    "Cam",
    "Wax",
    "Ado",
    "Hag",
    "Ful",
    "Onk",
    "Sadaasa",
    "Mud",
  ],
  month_stand_alone_narrow => [
    "A",
    "G",
    "B",
    "E",
    "C",
    "W",
    "A",
    "H",
    "F",
    "O",
    "S",
    "M",
  ],
  month_stand_alone_wide => [
    "Amajjii",
    "Guraandhala",
    "Bitootessa",
    "Eebila",
    "Caamsaa",
    "Waxabajjii",
    "Adoolessa",
    "Hagayya",
    "Fulbaana",
    "Onkoloolessa",
    "Sadaasa",
    "Mudde",
  ],
  name => "Oromo Ethiopia",
  native_language => "Oromoo",
  native_name => "Oromoo Itoophiyaa",
  native_script => undef,
  native_territory => "Itoophiyaa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kurmaana 1ffaa",
    "Kurmaana 2ffaa",
    "Kurmaana 3ffaa",
    "Kurmaana 4ffaa",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kurmaana 1ffaa",
    "Kurmaana 2ffaa",
    "Kurmaana 3ffaa",
    "Kurmaana 4ffaa",
  ],
  script => undef,
  territory => "Ethiopia",
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 46,
}
