{
  am_pm_abbreviated => [
    "priek\N{U+0161}p.",
    "p\N{U+0113}cp.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "G y. 'g'.",
    GyMMM => "G y. 'g'. MMM",
    GyMMMEd => "E, G y. 'g'. d. MMM",
    GyMMMd => "G y. 'g'. d. MMM",
    GyMd => "GGGGG dd-MM-y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd.MM.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-one" => "MMMM, W. 'ned\N{U+0113}\N{U+013c}a'",
    "MMMMW-count-other" => "MMMM, W. 'ned\N{U+0113}\N{U+013c}a'",
    "MMMMW-count-zero" => "MMMM, W. 'ned\N{U+0113}\N{U+013c}a'",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "dd.MM.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y. 'g'.",
    yM => "MM.y.",
    yMEd => "E, d.MM.y.",
    yMMM => "y. 'g'. MMM",
    yMMMEd => "E, y. 'g'. d. MMM",
    yMMMM => "y. 'g'. MMMM",
    yMMMd => "y. 'g'. d. MMM",
    yMd => "d.MM.y.",
    yQQQ => "y. 'g'. QQQ",
    yQQQQ => "y. 'g'. QQQQ",
    "yw-count-one" => "Y. 'g'. w. 'ned\N{U+0113}\N{U+013c}a'",
    "yw-count-other" => "Y. 'g'. w. 'ned\N{U+0113}\N{U+013c}a'",
    "yw-count-zero" => "Y. 'g'. w. 'ned\N{U+0113}\N{U+013c}a'",
  },
  code => "lv-LV",
  date_format_full => "EEEE, y. 'gada' d. MMMM",
  date_format_long => "y. 'gada' d. MMMM",
  date_format_medium => "y. 'gada' d. MMM",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pirmd.",
    "otrd.",
    "tre\N{U+0161}d.",
    "ceturtd.",
    "piektd.",
    "sestd.",
    "sv\N{U+0113}td.",
  ],
  day_format_narrow => [
    "P",
    "O",
    "T",
    "C",
    "P",
    "S",
    "S",
  ],
  day_format_wide => [
    "pirmdiena",
    "otrdiena",
    "tre\N{U+0161}diena",
    "ceturtdiena",
    "piektdiena",
    "sestdiena",
    "sv\N{U+0113}tdiena",
  ],
  day_stand_alone_abbreviated => [
    "Pirmd.",
    "Otrd.",
    "Tre\N{U+0161}d.",
    "Ceturtd.",
    "Piektd.",
    "Sestd.",
    "Sv\N{U+0113}td.",
  ],
  day_stand_alone_narrow => [
    "P",
    "O",
    "T",
    "C",
    "P",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Pirmdiena",
    "Otrdiena",
    "Tre\N{U+0161}diena",
    "Ceturtdiena",
    "Piektdiena",
    "Sestdiena",
    "Sv\N{U+0113}tdiena",
  ],
  era_abbreviated => [
    "p.m.\N{U+0113}.",
    "m.\N{U+0113}.",
  ],
  era_narrow => [
    "p.m.\N{U+0113}.",
    "m.\N{U+0113}.",
  ],
  era_wide => [
    "pirms m\N{U+016b}su \N{U+0113}ras",
    "m\N{U+016b}su \N{U+0113}r\N{U+0101}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%A, %Y. gada %e. %B, %H:%M:%S %Z",
  glibc_date_format => "%Y.%m.%d.",
  glibc_datetime_format => "%A, %Y. gada %e. %B, %H:%M:%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Latvian",
  month_format_abbreviated => [
    "janv.",
    "febr.",
    "marts",
    "apr.",
    "maijs",
    "j\N{U+016b}n.",
    "j\N{U+016b}l.",
    "aug.",
    "sept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janv\N{U+0101}ris",
    "febru\N{U+0101}ris",
    "marts",
    "apr\N{U+012b}lis",
    "maijs",
    "j\N{U+016b}nijs",
    "j\N{U+016b}lijs",
    "augusts",
    "septembris",
    "oktobris",
    "novembris",
    "decembris",
  ],
  month_stand_alone_abbreviated => [
    "janv.",
    "febr.",
    "marts",
    "apr.",
    "maijs",
    "j\N{U+016b}n.",
    "j\N{U+016b}l.",
    "aug.",
    "sept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janv\N{U+0101}ris",
    "febru\N{U+0101}ris",
    "marts",
    "apr\N{U+012b}lis",
    "maijs",
    "j\N{U+016b}nijs",
    "j\N{U+016b}lijs",
    "augusts",
    "septembris",
    "oktobris",
    "novembris",
    "decembris",
  ],
  name => "Latvian Latvia",
  native_language => "latvie\N{U+0161}u",
  native_name => "latvie\N{U+0161}u Latvija",
  native_script => undef,
  native_territory => "Latvija",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1.\N{U+00a0}cet.",
    "2.\N{U+00a0}cet.",
    "3.\N{U+00a0}cet.",
    "4.\N{U+00a0}cet.",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. ceturksnis",
    "2. ceturksnis",
    "3. ceturksnis",
    "4. ceturksnis",
  ],
  quarter_stand_alone_abbreviated => [
    "1.\N{U+00a0}cet.",
    "2.\N{U+00a0}cet.",
    "3.\N{U+00a0}cet.",
    "4.\N{U+00a0}cet.",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. ceturksnis",
    "2. ceturksnis",
    "3. ceturksnis",
    "4. ceturksnis",
  ],
  script => undef,
  territory => "Latvia",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
