{
  am_pm_abbreviated => [
    "AN",
    "EW",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "y/M/d",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ak",
  date_format_full => "EEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe",
  ],
  day_format_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K",
  ],
  day_format_wide => [
    "Dwoada",
    "Benada",
    "Wukuada",
    "Yawoada",
    "Fiada",
    "Memeneda",
    "Kwasiada",
  ],
  day_stand_alone_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe",
  ],
  day_stand_alone_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K",
  ],
  day_stand_alone_wide => [
    "Dwoada",
    "Benada",
    "Wukuada",
    "Yawoada",
    "Fiada",
    "Memeneda",
    "Kwasiada",
  ],
  era_abbreviated => [
    "AK",
    "KE",
  ],
  era_narrow => [
    "AK",
    "KE",
  ],
  era_wide => [
    "Ansa Kristo",
    "Kristo Akyi",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Akan",
  month_format_abbreviated => [
    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "\N{U+0186}gyefo\N{U+0254}",
    "\N{U+0186}b\N{U+025b}nem",
    "Oforisuo",
    "K\N{U+0254}t\N{U+0254}nimma",
    "Ay\N{U+025b}wohomumu",
    "Kutawonsa",
    "\N{U+0186}sanaa",
    "\N{U+0190}b\N{U+0254}",
    "Ahinime",
    "Obubuo",
    "\N{U+0186}p\N{U+025b}nimma",
  ],
  month_format_narrow => [
    "\N{U+0186}",
    "\N{U+0186}",
    "\N{U+0186}",
    "O",
    "K",
    "A",
    "K",
    "\N{U+0186}",
    "\N{U+0190}",
    "A",
    "O",
    "\N{U+0186}",
  ],
  month_format_wide => [
    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "\N{U+0186}gyefo\N{U+0254}",
    "\N{U+0186}b\N{U+025b}nem",
    "Oforisuo",
    "K\N{U+0254}t\N{U+0254}nimma",
    "Ay\N{U+025b}wohomumu",
    "Kutawonsa",
    "\N{U+0186}sanaa",
    "\N{U+0190}b\N{U+0254}",
    "Ahinime",
    "Obubuo",
    "\N{U+0186}p\N{U+025b}nimma",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "\N{U+0186}gyefo\N{U+0254}",
    "\N{U+0186}b\N{U+025b}nem",
    "Oforisuo",
    "K\N{U+0254}t\N{U+0254}nimma",
    "Ay\N{U+025b}wohomumu",
    "Kutawonsa",
    "\N{U+0186}sanaa",
    "\N{U+0190}b\N{U+0254}",
    "Ahinime",
    "Obubuo",
    "\N{U+0186}p\N{U+025b}nimma",
  ],
  month_stand_alone_narrow => [
    "\N{U+0186}",
    "\N{U+0186}",
    "\N{U+0186}",
    "O",
    "K",
    "A",
    "K",
    "\N{U+0186}",
    "\N{U+0190}",
    "A",
    "O",
    "\N{U+0186}",
  ],
  month_stand_alone_wide => [
    "\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "\N{U+0186}gyefo\N{U+0254}",
    "\N{U+0186}b\N{U+025b}nem",
    "Oforisuo",
    "K\N{U+0254}t\N{U+0254}nimma",
    "Ay\N{U+025b}wohomumu",
    "Kutawonsa",
    "\N{U+0186}sanaa",
    "\N{U+0190}b\N{U+0254}",
    "Ahinime",
    "Obubuo",
    "\N{U+0186}p\N{U+025b}nimma",
  ],
  name => "Akan",
  native_language => "Akan",
  native_name => "Akan",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K\N{U+0254}ta1",
    "K\N{U+0254}ta2",
    "K\N{U+0254}ta3",
    "K\N{U+0254}ta4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "K\N{U+0254}ta a \N{U+025b}di kan",
    "k\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmienu",
    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmi\N{U+025b}nsa",
    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so nnan",
  ],
  quarter_stand_alone_abbreviated => [
    "K\N{U+0254}ta1",
    "K\N{U+0254}ta2",
    "K\N{U+0254}ta3",
    "K\N{U+0254}ta4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "K\N{U+0254}ta a \N{U+025b}di kan",
    "k\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmienu",
    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so mmi\N{U+025b}nsa",
    "K\N{U+0254}ta a \N{U+025b}t\N{U+0254} so nnan",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 46,
}
