{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E a\N{U+202f}h:mm",
    Ehms => "E a\N{U+202f}h:mm:ss",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "d-M-y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "dd-MM, E",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "MMMM -'acho' 'suman' W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "a\N{U+202f}h",
    hm => "a\N{U+202f}h:mm",
    hms => "a\N{U+202f}h:mm:ss",
    hmsv => "a\N{U+202f}h:mm:ss v",
    hmv => "a\N{U+202f}h:mm v",
    ms => "mm:ss",
    y => "y",
    yM => "M-y",
    yMEd => "E, d-M-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d-M-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "Y -'acho' 'suman' w",
  },
  code => "kok-Latn",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d-M-yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Som",
    "Mon",
    "Bud",
    "Bre",
    "Suk",
    "Son",
    "Ait",
  ],
  day_format_narrow => [
    "S",
    "M",
    "B",
    "B",
    "S",
    "S",
    "A",
  ],
  day_format_wide => [
    "Somar",
    "Mongllar",
    "Budhvar",
    "Birestar",
    "Sukrar",
    "Sonvar",
    "Aitar",
  ],
  day_stand_alone_abbreviated => [
    "Som",
    "Mon",
    "Bud",
    "Bre",
    "Suk",
    "Son",
    "Ait",
  ],
  day_stand_alone_narrow => [
    "S",
    "M",
    "B",
    "B",
    "S",
    "S",
    "A",
  ],
  day_stand_alone_wide => [
    "Somar",
    "Mongllar",
    "Budhvar",
    "Birestar",
    "Sukrar",
    "Sonvar",
    "Aitar",
  ],
  era_abbreviated => [
    "KA",
    "AD",
  ],
  era_narrow => [
    "K",
    "A",
  ],
  era_wide => [
    "Krista Adim",
    "Anno Domini",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Konkani",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nov",
    "Dez",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janer",
    "Febrer",
    "Mars",
    "Abril",
    "Mai",
    "Jun",
    "Julai",
    "Agost",
    "Setembr",
    "Otubr",
    "Novembr",
    "Dezembr",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "Mai",
    "Jun",
    "Jul",
    "Ago",
    "Set",
    "Otu",
    "Nov",
    "Dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janer",
    "Febrer",
    "Mars",
    "Abril",
    "Mai",
    "Jun",
    "Julai",
    "Agost",
    "Setembr",
    "Otubr",
    "Novembr",
    "Dezembr",
  ],
  name => "Konkani Latin",
  native_language => "Konknni",
  native_name => "Konknni Romi",
  native_script => "Romi",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Timh1",
    "Timh2",
    "Timh3",
    "Timh4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1lem timhoinallem",
    "2rem timhoinallem",
    "3rem timhoinallem",
    "4tem timhoinallem",
  ],
  quarter_stand_alone_abbreviated => [
    "Timh1",
    "Timh2",
    "Timh3",
    "Timh4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1lem timhoinallem",
    "2rem timhoinallem",
    "3rem timhoinallem",
    "4tem timhoinallem",
  ],
  script => "Latin",
  territory => undef,
  time_format_full => "a\N{U+202f}h:mm:ss\N{U+202f}zzzz",
  time_format_long => "a\N{U+202f}h:mm:ss z",
  time_format_medium => "a\N{U+202f}h:mm:ss",
  time_format_short => "a\N{U+202f}h:mm",
  variant => undef,
  version => 46,
}
