{
  am_pm_abbreviated => [
    "kang\N{U+2019}ama",
    "kingoto",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "rof-TZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ijt",
    "Ijn",
    "Ijtn",
    "Alh",
    "Iju",
    "Ijm",
    "Ijp",
  ],
  day_format_narrow => [
    3,
    4,
    5,
    6,
    7,
    1,
    2,
  ],
  day_format_wide => [
    "Ijumatatu",
    "Ijumanne",
    "Ijumatano",
    "Alhamisi",
    "Ijumaa",
    "Ijumamosi",
    "Ijumapili",
  ],
  day_stand_alone_abbreviated => [
    "Ijt",
    "Ijn",
    "Ijtn",
    "Alh",
    "Iju",
    "Ijm",
    "Ijp",
  ],
  day_stand_alone_narrow => [
    3,
    4,
    5,
    6,
    7,
    1,
    2,
  ],
  day_stand_alone_wide => [
    "Ijumatatu",
    "Ijumanne",
    "Ijumatano",
    "Alhamisi",
    "Ijumaa",
    "Ijumamosi",
    "Ijumapili",
  ],
  era_abbreviated => [
    "KM",
    "BM",
  ],
  era_narrow => [
    "KM",
    "BM",
  ],
  era_wide => [
    "Kabla ya Mayesu",
    "Baada ya Mayesu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Rombo",
  month_format_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
    "M5",
    "M6",
    "M7",
    "M8",
    "M9",
    "M10",
    "M11",
    "M12",
  ],
  month_format_narrow => [
    "K",
    "K",
    "K",
    "K",
    "T",
    "S",
    "S",
    "N",
    "T",
    "I",
    "I",
    "I",
  ],
  month_format_wide => [
    "Mweri wa kwanza",
    "Mweri wa kaili",
    "Mweri wa katatu",
    "Mweri wa kaana",
    "Mweri wa tanu",
    "Mweri wa sita",
    "Mweri wa saba",
    "Mweri wa nane",
    "Mweri wa tisa",
    "Mweri wa ikumi",
    "Mweri wa ikumi na moja",
    "Mweri wa ikumi na mbili",
  ],
  month_stand_alone_abbreviated => [
    "M1",
    "M2",
    "M3",
    "M4",
    "M5",
    "M6",
    "M7",
    "M8",
    "M9",
    "M10",
    "M11",
    "M12",
  ],
  month_stand_alone_narrow => [
    "K",
    "K",
    "K",
    "K",
    "T",
    "S",
    "S",
    "N",
    "T",
    "I",
    "I",
    "I",
  ],
  month_stand_alone_wide => [
    "Mweri wa kwanza",
    "Mweri wa kaili",
    "Mweri wa katatu",
    "Mweri wa kaana",
    "Mweri wa tanu",
    "Mweri wa sita",
    "Mweri wa saba",
    "Mweri wa nane",
    "Mweri wa tisa",
    "Mweri wa ikumi",
    "Mweri wa ikumi na moja",
    "Mweri wa ikumi na mbili",
  ],
  name => "Rombo Tanzania",
  native_language => "Kihorombo",
  native_name => "Kihorombo Tanzania",
  native_script => undef,
  native_territory => "Tanzania",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Robo ya kwanza",
    "Robo ya kaili",
    "Robo ya katatu",
    "Robo ya kaana",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Robo ya kwanza",
    "Robo ya kaili",
    "Robo ya katatu",
    "Robo ya kaana",
  ],
  script => undef,
  territory => "Tanzania",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
