{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "dd/MM/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "L",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "W'\N{U+00aa}' 'setemana' 'de' MMMM",
    "MMMMW-count-other" => "W'\N{U+00aa}' 'setemana' 'de' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss\N{U+202f}a (v)",
    hmv => "h:mm\N{U+202f}a (v)",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "w'\N{U+00aa}' 'setemana' 'de''l' Y",
    "yw-count-other" => "w'\N{U+00aa}' 'setemana' 'de''l' Y",
  },
  code => "vec",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mer",
    "zob",
    "v\N{U+00e8}n",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "Z",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "luni",
    "marti",
    "m\N{U+00e8}rcore",
    "zoba",
    "v\N{U+00e8}nare",
    "sabo",
    "dom\N{U+00e9}nega",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mer",
    "zob",
    "v\N{U+00e8}n",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "Z",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "luni",
    "marti",
    "m\N{U+00e8}rcore",
    "zoba",
    "v\N{U+00e8}nare",
    "sabo",
    "dom\N{U+00e9}nega",
  ],
  era_abbreviated => [
    "v.C.",
    "d.C.",
  ],
  era_narrow => [
    "v.C.",
    "d.C.",
  ],
  era_wide => [
    "vanti Cristo",
    "dasp\N{U+00f2} Cristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Venetian",
  month_format_abbreviated => [
    "jen",
    "feb",
    "mar",
    "apr",
    "maj",
    "jug",
    "luj",
    "ago",
    "set",
    "oto",
    "nov",
    "dez",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "jenaro",
    "febraro",
    "marso",
    "aprile",
    "majo",
    "jugno",
    "lujo",
    "agosto",
    "setenbre",
    "otobre",
    "novenbre",
    "dezenbre",
  ],
  month_stand_alone_abbreviated => [
    "jen",
    "feb",
    "mar",
    "apr",
    "maj",
    "jug",
    "luj",
    "ago",
    "set",
    "oto",
    "nov",
    "dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "jenaro",
    "febraro",
    "marso",
    "aprile",
    "majo",
    "jugno",
    "lujo",
    "agosto",
    "setenbre",
    "otobre",
    "novenbre",
    "dezenbre",
  ],
  name => "Venetian",
  native_language => "veneto",
  native_name => "veneto",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
