{
  am_pm_abbreviated => [
    "Tesiran",
    "Teipa",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "saq",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Kun",
    "Ong",
    "Ine",
    "Ile",
    "Sap",
    "Kwe",
    "Are",
  ],
  day_format_narrow => [
    "K",
    "O",
    "I",
    "I",
    "S",
    "K",
    "A",
  ],
  day_format_wide => [
    "Mderot ee kuni",
    "Mderot ee ong\N{U+2019}wan",
    "Mderot ee inet",
    "Mderot ee ile",
    "Mderot ee sapa",
    "Mderot ee kwe",
    "Mderot ee are",
  ],
  day_stand_alone_abbreviated => [
    "Kun",
    "Ong",
    "Ine",
    "Ile",
    "Sap",
    "Kwe",
    "Are",
  ],
  day_stand_alone_narrow => [
    "K",
    "O",
    "I",
    "I",
    "S",
    "K",
    "A",
  ],
  day_stand_alone_wide => [
    "Mderot ee kuni",
    "Mderot ee ong\N{U+2019}wan",
    "Mderot ee inet",
    "Mderot ee ile",
    "Mderot ee sapa",
    "Mderot ee kwe",
    "Mderot ee are",
  ],
  era_abbreviated => [
    "KK",
    "BK",
  ],
  era_narrow => [
    "KK",
    "BK",
  ],
  era_wide => [
    "Kabla ya Christo",
    "Baada ya Christo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Samburu",
  month_format_abbreviated => [
    "Obo",
    "Waa",
    "Oku",
    "Ong",
    "Ime",
    "Ile",
    "Sap",
    "Isi",
    "Saa",
    "Tom",
    "Tob",
    "Tow",
  ],
  month_format_narrow => [
    "O",
    "W",
    "O",
    "O",
    "I",
    "I",
    "S",
    "I",
    "S",
    "T",
    "T",
    "T",
  ],
  month_format_wide => [
    "Lapa le obo",
    "Lapa le waare",
    "Lapa le okuni",
    "Lapa le ong\N{U+2019}wan",
    "Lapa le imet",
    "Lapa le ile",
    "Lapa le sapa",
    "Lapa le isiet",
    "Lapa le saal",
    "Lapa le tomon",
    "Lapa le tomon obo",
    "Lapa le tomon waare",
  ],
  month_stand_alone_abbreviated => [
    "Obo",
    "Waa",
    "Oku",
    "Ong",
    "Ime",
    "Ile",
    "Sap",
    "Isi",
    "Saa",
    "Tom",
    "Tob",
    "Tow",
  ],
  month_stand_alone_narrow => [
    "O",
    "W",
    "O",
    "O",
    "I",
    "I",
    "S",
    "I",
    "S",
    "T",
    "T",
    "T",
  ],
  month_stand_alone_wide => [
    "Lapa le obo",
    "Lapa le waare",
    "Lapa le okuni",
    "Lapa le ong\N{U+2019}wan",
    "Lapa le imet",
    "Lapa le ile",
    "Lapa le sapa",
    "Lapa le isiet",
    "Lapa le saal",
    "Lapa le tomon",
    "Lapa le tomon obo",
    "Lapa le tomon waare",
  ],
  name => "Samburu",
  native_language => "Kisampur",
  native_name => "Kisampur",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Robo 1",
    "Robo 2",
    "Robo 3",
    "Robo 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
