{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E, h:mm B",
    EBhms => "E, h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm\N{U+202f}a",
    Ehms => "E, h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d.M.y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "'edema' W MMMM",
    "MMMMW-count-other" => "'edema' W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d.M.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, d.M.y",
    yMMM => "LLL y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'edema' w 'dl' Y",
    "yw-count-other" => "'edema' w 'dl' Y",
  },
  code => "lld-IT",
  date_format_full => "EEEE, d MMMM 'dl' y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "l\N{U+00f6}n",
    "mert",
    "merc",
    "j\N{U+00f6}b",
    "v\N{U+00eb}n",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "l\N{U+00f6}nesc",
    "mertesc",
    "mercui",
    "j\N{U+00f6}bia",
    "v\N{U+00eb}ndres",
    "sabeda",
    "dom\N{U+00eb}nia",
  ],
  day_stand_alone_abbreviated => [
    "l\N{U+00f6}n",
    "mert",
    "merc",
    "j\N{U+00f6}b",
    "v\N{U+00eb}n",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "l\N{U+00f6}nesc",
    "mertesc",
    "mercui",
    "j\N{U+00f6}bia",
    "v\N{U+00eb}ndres",
    "sabeda",
    "dom\N{U+00eb}nia",
  ],
  era_abbreviated => [
    "dan G.C.",
    "AD",
  ],
  era_narrow => [
    "dan G.C.",
    "AD",
  ],
  era_wide => [
    "dan Gej\N{U+00fa} Crist",
    "A.D.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => undef,
  month_format_abbreviated => [
    "de jen\N{U+00e1}",
    "de for\N{U+00e1}",
    "de merz",
    "d\N{U+2019}aur\N{U+00ed}",
    "de ma",
    "de j\N{U+00fc}gn",
    "de mess\N{U+00e9}",
    "d\N{U+2019}aost",
    "de set",
    "d\N{U+2019}oto",
    "de nov",
    "de dez",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "M",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "de jen\N{U+00e1}",
    "de for\N{U+00e1}",
    "de merz",
    "d\N{U+2019}aur\N{U+00ed}",
    "de ma",
    "de j\N{U+00fc}gn",
    "de mess\N{U+00e9}",
    "d\N{U+2019}aost",
    "de set\N{U+00eb}mber",
    "d\N{U+2019}otober",
    "de nov\N{U+00eb}mber",
    "de dez\N{U+00eb}mber",
  ],
  month_stand_alone_abbreviated => [
    "jen\N{U+00e1}",
    "for\N{U+00e1}",
    "merz",
    "aur\N{U+00ed}",
    "ma",
    "j\N{U+00fc}gn",
    "mess\N{U+00e9}",
    "aost",
    "set",
    "oto",
    "nov",
    "dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "M",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "jen\N{U+00e1}",
    "for\N{U+00e1}",
    "merz",
    "aur\N{U+00ed}",
    "ma",
    "j\N{U+00fc}gn",
    "mess\N{U+00e9}",
    "aost",
    "set\N{U+00eb}mber",
    "otober",
    "nov\N{U+00eb}mber",
    "dez\N{U+00eb}mber",
  ],
  name => "Italy",
  native_language => "ladin",
  native_name => "ladin Talia",
  native_script => undef,
  native_territory => "Talia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "pr\N{U+00f6}m trimester",
    "secundo trimester",
    "terzo trimester",
    "cuarto trimester",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "pr\N{U+00f6}m trimester",
    "secundo trimester",
    "terzo trimester",
    "cuarto trimester",
  ],
  script => undef,
  territory => "Italy",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
